Update collective APIs naming (#77)
* Update the naming convention for collective APIs to ensure consistency across the interface. * Move all collective API declarations to rocshmem_COLL.hpp * The following APIs were updated as part of this change: - `barrier` - `barrier_all` - `sync` - `sync_all` - `all_to_all` - `broadcast` - `fcollect` - `all_reduce` * Update header file generation code for collective APIs
This commit is contained in:
committed by
GitHub
parent
5e49567b6c
commit
68421895d6
@@ -37,7 +37,7 @@ __global__ void allreduce_test(int *source, int *dest, size_t nelem,
|
||||
rocshmem_wg_ctx_create(ctx_type, &ctx);
|
||||
int num_pes = rocshmem_ctx_n_pes(ctx);
|
||||
|
||||
rocshmem_ctx_int_sum_wg_reduce(ctx, team, dest, source, nelem);
|
||||
rocshmem_ctx_int_sum_reduce_wg(ctx, team, dest, source, nelem);
|
||||
|
||||
rocshmem_ctx_quiet(ctx);
|
||||
__syncthreads();
|
||||
|
||||
@@ -37,7 +37,7 @@ __global__ void alltoall_test(int *source, int *dest, size_t nelem,
|
||||
rocshmem_wg_ctx_create(ctx_type, &ctx);
|
||||
int num_pes = rocshmem_ctx_n_pes(ctx);
|
||||
|
||||
rocshmem_ctx_int_wg_alltoall(ctx, team, dest, source, nelem);
|
||||
rocshmem_ctx_int_alltoall_wg(ctx, team, dest, source, nelem);
|
||||
|
||||
rocshmem_ctx_quiet(ctx);
|
||||
__syncthreads();
|
||||
|
||||
@@ -37,7 +37,7 @@ __global__ void broadcast_test(int *source, int *dest, size_t nelem,
|
||||
rocshmem_wg_ctx_create(ctx_type, &ctx);
|
||||
int num_pes = rocshmem_ctx_n_pes(ctx);
|
||||
|
||||
rocshmem_ctx_int_wg_broadcast(ctx, team, dest, source, nelem, root);
|
||||
rocshmem_ctx_int_broadcast_wg(ctx, team, dest, source, nelem, root);
|
||||
|
||||
rocshmem_ctx_quiet(ctx);
|
||||
__syncthreads();
|
||||
|
||||
Reference in New Issue
Block a user